
# Slot: local_names




URI: [linkml:local_names](https://w3id.org/linkml/local_names)


## Domain and Range

[Element](Element.md) &#8594;  <sub>0..\*</sub> local_name

## Parents


## Children


## Used by

 * class_definition
 * definition
 * [Element](Element.md)
 * enum_definition
 * schema_definition
 * slot_definition
 * subset_definition
 * type_definition
